@@ -4,7 +4,6 @@ import shutil
 import subprocess
 import sys
 import tempfile
-import unittest
 from ast import literal_eval
 from pprint import pformat
 
@@ -319,5 +318,14 @@ replace_switch def xyz $switches""").split()),
         assert_found_assignment("LL_BUILD", "darwin release", stdout)
         assert_found_assignment("SOMETHING_ELSE", "something else", stdout)
 
-if __name__ == '__main__':
-    unittest.main()
+    @needs_cygwin
+    def test_vstoolset_set(self):
+        with envvar("AUTOBUILD_VSVER", "170"):
+            vars = self.read_variables(self.find_data("empty"))
+        self.assertEqual(vars["AUTOBUILD_WIN_VSTOOLSET"], "v143")
+
+    @needs_cygwin
+    def test_vstoolset_not_set_if_vsver_unrecognized(self):
+        with envvar("AUTOBUILD_VSVER", "171"):
+            vars = self.read_variables(self.find_data("empty"))
+        self.assertTrue("AUTOBUILD_WIN_VSTOOLSET" not in vars)
